package com.ibm.mobileservices.sample.VNurseCL;
import com.ibm.db2ess.cl.*;
import java.util.*;
import java.io.*;														// To get the File IO class

/* IBM Confidential
 *
 * Product ID: 5724-D04
 *
 * (C) Copyright IBM Corp. 2003
 *
 * The source code for this program is not published or otherwise divested
 * of its trade secrets, irrespective of what has been deposited with the
 * U.S. Copyright Office.
 */

/**
 * <pre>
 * Descriptive Name:  Log data on screen or file
 *
 * Description:
 *    This class is called by Custom Logic to monitor synchronization/replication events
 *
 *    Modifications:
 *
 *    Date      Author                 	Category             Defect/Feature
 *              Description
 *
 *  2003/04/01  Thanh Pham             	New Code             CustomLogic
 *              Initial code.
 *
 * </pre>
 *
 *    @see com.ibm.db2ess.cl.AfterTableReplicatePolicy
 * 		@see com.ibm.db2ess.cl.CLException
 *    @author Thanh Pham
 */
public class SampleDataLog {

	public static final int LOG_ALL=999999;
	public static final int LOG_0=0;
	public static final int LOG_1=1;
//	private static final String logDataFile = "C:\\SampleDataLog.txt";	// For Windows platform

  /**
   * This instantiates the singleton SampleDataLog object.
   */
	private static final SampleDataLog INSTANCE= new SampleDataLog();	// Create the singleton


  /**
   * This method returns the unique instance of the SampleDataLog.
   *
   */
  public static SampleDataLog getInstance() {
  	return INSTANCE;
  }

	public void writeOut(String logRecord) {
		System.out.println(logRecord);	// Also print on screen

		// Open the data log file, write to it and close the file
//		FileWriter toFile = null;
//		try {
//			toFile = new FileWriter(logDataFile, true);
//			toFile.write(logRecord);
//			toFile.write("\n");
//		}
//		catch (IOException e) {System.out.println("ERROR");}
//		finally {
//			if (toFile != null) try { toFile.close(); } catch (IOException e) {System.out.println("ERROR");}
//		}
	}

  public void log(CLRecord clRecord, int filter) {
		writeOut("=======> Log CLRecord");

		if (clRecord != null) {
			if (clRecord.conflictExists()) {
				writeOut("CLRecord.1.Conflicts - Exists");
			} else {
			 	writeOut("CLRecord.1.Conflicts - No conflicts");
			}

			CLColumnInfo[] clColumnInfoArray = clRecord.getColumnsInfo();
			if (clColumnInfoArray != null) {
				writeOut("CLRecord.2.CLColumnInfo - " + clColumnInfoArray.length);
				// List all the CLColumnInfos
				for (int i=0; i < clColumnInfoArray.length; i++) {
					log(clColumnInfoArray[i], filter);
				}
			} else {
				writeOut("CLRecord.2.No column info");
			}

			CLCandidate[] clCandidateArray = clRecord.getCandidates();
			if (clCandidateArray != null) {
				writeOut("CLRecord.3.CLCandidate - " + clCandidateArray.length);
				// List all the CLCandidates
				for (int i=0; i < clCandidateArray.length; i++) {
					log(clCandidateArray[i], filter);
				}
			} else {
				writeOut("CLRecord.3.No candidate");
			}

			if (clRecord.getRejectNotification()) {
				writeOut("CLRecord.4.Reject notification - True");
			} else {
			 	writeOut("CLRecord.4.Reject notification - False");
			}

			CLCandidate clCandidate = clRecord.getPrevailingCandidate();
			if (clCandidate != null) {
				writeOut("CLRecord.5.CLCandidate prevailing - Exist");
				log(clCandidate, filter);
			} else {
				writeOut("CLRecord.5.CLCandidate prevailing - Not exist");
			}

		}

	}

  public void log(CLCandidate clCandidate, int filter) {
		writeOut("=======> Log CLCandidate");

		if (clCandidate != null) {
			// Computes the correspondent code
			char c = 'N';
			if (clCandidate.fromCustomLogic()) {
				c = 'C';
			} else if (clCandidate.fromSource()) {
				c = 'S';
			}	else if (clCandidate.fromUser()) {
				c = 'U';
			}
			writeOut("CLCandidate.1.from - " + c);

			CLCorrespondent clCorrespondent = clCandidate.getAuthor();
			if (clCandidate != null) {
				writeOut("CLCandidate.2.Author - Exist");
				log(clCorrespondent, filter);
			} else {
				writeOut("CLCandidate.2.Author - Not exist");
			}

			writeOut("CLCandidate.3.Operation - " + clCandidate.getOp());

			if (clCandidate.isRejected()) {
				writeOut("CLCandidate.4.Rejected - true");
			} else {
				writeOut("CLCandidate.4.Rejected - false");
			}

		}
	}

  public void log(CLCorrespondent clCorrespondent, int filter) {
		//System.out.println("Log CLCorrespondent");
		writeOut("=======> Log CLCorrespondent");

		if (clCorrespondent != null) {
			// Computes the correspondent code
			char c = 'N';
			if (clCorrespondent.isCustomLogic()) {
				c = 'C';
			} else if (clCorrespondent.isSource()) {
				c = 'S';
			}	else if (clCorrespondent.isUser()) {
				c = 'U';
			}

			// Log CLCorrespondent
			writeOut("CLCorrespondent: " +
								c + "; " +
								clCorrespondent.getUserName() + "; " +
								clCorrespondent.getDeviceId());
		} else {
			writeOut("No clCorrespondent");
		}

	}

  public void log(CLColumnInfo clColumnInfo, int filter) {
		//System.out.println("Log CLResult");
		writeOut("=======> Log CLColumnInfo");

		if (clColumnInfo != null) {
			// Log CLColumnInfo
			writeOut("CLColumnInfo: Name(" +
								clColumnInfo.getName() + "), TypeName(" +
								clColumnInfo.getTypeName() + "), SQLType(" +
								clColumnInfo.getType() + "), KeySeq(" +
								clColumnInfo.getKeySeq() + "), Length(" +
								clColumnInfo.getLength() + "), Scale(" +
								clColumnInfo.getScale() + "), Nullable(" +
								clColumnInfo.isNullable() + ")");
		} else {
			writeOut("No clColumnInfo");
		}

	}

  /**
   * This method implements the call to all CLResult methods and logs the results.
   *
   */
  public void log(CLResult clResult, int filter) {
		//System.out.println("Log CLResult");
		writeOut("=======> Log CLResult");

		if (clResult != null) {
			// Log fatal exception result
			CLException fatalException = clResult.getFatalException();
			if (fatalException == null) {
				writeOut("CLResult.1.Fatal Exception - None");
			} else {
				writeOut("CLResult.1.Fatal Exception - Exist");
				log(fatalException, filter);
			}

			// Log statistic results
			writeOut("CLResult.2.Number of rows deleted: " + clResult.getUserDeleteCount());
			writeOut("CLResult.3.Number of rows inserted: " + clResult.getUserInsertCount());
			writeOut("CLResult.4.Number of rows rejected: " + clResult.getUserRejectCount());
			writeOut("CLResult.5.Number of rows updated: " + clResult.getUserUpdateCount());

			// Log CLCandidate exception results
			CLCandidateException[] clCandidateExceptionArray = clResult.getExceptions();
			if (clCandidateExceptionArray == null) {
				writeOut("CLResult.6.CLCandidateExceptions - None");
			} else {
				writeOut("CLResult.6.CLCandidateExceptions - Occured " + clCandidateExceptionArray.length);
				// List all the CLCandidateExceptions
				for (int i=0; i < clCandidateExceptionArray.length; i++) {
					log(clCandidateExceptionArray[i], filter);
				}
			}
		} else {
			writeOut("No clResult.");
		}


	}

  /**
   * This method implements the call to all CLCandidateException methods and logs the results.
   *
   */
  public void log(CLCandidateException clCandidateException, int filter) {
		//System.out.println("Log CLException");
		writeOut("=======> Log CLCandidateException");

		writeOut("CLCandidateException.1.getCandidate()");
		writeOut("CLCandidateException.2.Message: " + clCandidateException.getMessage());

		Exception e = clCandidateException.getOriginalException();
		if (e == null) {
			writeOut("CLCandidateException.3.OriginalException - None");
		} else {
			writeOut("CLCandidateException.3.OriginalException Message: " + e.getMessage());
		}

	}

  /**
   * This method implements the call to all CLException methods and logs the results.
   *
   */
  public void log(CLException clException, int filter) {
		//System.out.println("Log CLException");
		writeOut("=======> Log CLException");

		writeOut("CLException.1.Message: " + clException.getMessage());

		Exception e = clException.getOriginalException();
		if (e == null) {
			writeOut("CLException.2.OriginalException - None");
		} else {
			writeOut("CLException.3.OriginalException Message: " + e.getMessage());
		}

	}

//*===================================================================================


}
 