package com.ibm.mobileservices.sample.VNurseCL;
import com.ibm.db2ess.cl.*;

/* IBM Confidential
 *
 * Product ID: 5724-D04
 *
 * (C) Copyright IBM Corp. 2003
 *
 * The source code for this program is not published or otherwise divested
 * of its trade secrets, irrespective of what has been deposited with the
 * U.S. Copyright Office.
 */

/**
 * <pre>
 * Descriptive Name:  Custom Logic during the processing of input synchronization data.
 *
 * Description:
 *    This class is called by Sync Server during the processing of input synchronization data.
 *    For demonstration purpose, any negative primary key is mapped to a positive one by changing the sign.
 *
 *    Modifications:
 *
 *    Date      Author                 	Category             Defect/Feature
 *              Description
 *
 *  2003/04/01  Thanh Pham             	New Code             CustomLogic
 *              Initial code.
 *
 * </pre>
 *
 *    @see com.ibm.db2ess.cl.TableSyncInPolicy
 * 		@see com.ibm.db2ess.cl.CLException
 *    @author Thanh Pham
 */
public class VNurseTableSyncInPolicy extends TablePolicy {

  /**
   * This method will be invoked by the SyncServer during the processing of input synchronization data.
   *
   * @exception com.ibm.db2ess.cl.CLException
   * Custom logic generated or encountered exception.
   */
  public void execute(CLRecord iRecord) throws CLException {

		SampleDataLog sdl = SampleDataLog.getInstance();
		String s = new String("\n=====> TableSyncInPolicy");

		sdl.writeOut(s);

		if (iRecord != null) {

			// Log the data
			sdl.log(iRecord, sdl.LOG_ALL);

			// Go thru the candidate to look if we need to perform Primary Key mapping
			// The primary key column index is 0 in this sample.
			int pkColInd = 0;

			// Get the candidate array and process it
			CLCandidate[] clCandidateArray = iRecord.getCandidates();
			if (clCandidateArray != null) {
				// Scan all the the CLCandidates
				for (int i=0; i < clCandidateArray.length; i++) {
					// For each CLCandidate, look into the column 'MedicalRecordID' (first column)
					// If this is a negative value, then changes to a positive one
					try {

						if (clCandidateArray[i].getOp() == CLCandidate.Op.INSERT) {
							int oldINT = clCandidateArray[i].getInt(pkColInd);
							sdl.writeOut("=========> PK column value: " + oldINT);

							if (oldINT < 0) {
								sdl.writeOut("Found a record to be PK mapped");

								// First, we clone the candidate
								CLCandidate clone = iRecord.createCLCandidate(clCandidateArray[i]);

								if (clone != null) {
									// Now we can operate on the clone

									int newINT = 0-oldINT;
									sdl.writeOut("Old values: " + oldINT + ". New values: " + newINT);

									if (clone.setField(pkColInd, newINT)) {
										sdl.writeOut("New PK value sets successfully");

										// Now force the candidate
										// Sync server is responsible to free the clone when we exit
										iRecord.force(clone);
									} else {
										sdl.writeOut("New PK value fails to set");
									}
								} else {
									sdl.writeOut("!!!Cannot clone the candidate!!!");
								}
							}
						}
					}
					catch (CLCandidateException clCandidateException) {
						sdl.writeOut("!!!CLCandidateException occurs!!!");
						sdl.log(clCandidateException, sdl.LOG_ALL);
					}
				} // End of FOR loop
			} else {
				sdl.writeOut("!!! ERROR !!! - Conflicts with no candidate ");
			}

			// Apply the Custom Logic on this record
			try {
				iRecord.apply();
				if (iRecord.applied()) {
					sdl.writeOut("Record applied successfully");
				} else {
					sdl.writeOut("Record applied fail");
				}
			}
			catch (CLCandidateException clCandidateException) {
				sdl.log(clCandidateException, sdl.LOG_ALL);
			}
		} else {
			sdl.writeOut("No CLRecord input parameter.");
		}

	}

} 